#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# opensecurity-dialog
# 
# an opensecurity dialog
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright 2013-2014 X-Net and AIT Austrian Institute of Technology
# 
# 
#     X-Net Services GmbH
#     Elisabethstrasse 1
#     4020 Linz
#     AUSTRIA
#     https://www.x-net.at
# 
#     AIT Austrian Institute of Technology
#     Donau City Strasse 1
#     1220 Wien
#     AUSTRIA
#     http://www.ait.ac.at
# 
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import argparse
import os
import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

# local
from ui import *


# ------------------------------------------------------------
# code


def main():
    
    # parse command line
    parser = argparse.ArgumentParser(description = 'OpenSecurity Dialog.')
    parser.add_argument('mode', metavar='MODE', help='dialog mode: \'password\', \'credentials\', \'keyfile\', \'notification-information\', \'notification-warning\' or \'notification-critical\'')
    parser.add_argument('text', metavar='TEXT', help='text to show')
    args = parser.parse_args()
    
    a = QtGui.QApplication(sys.argv)
    
    if args.mode == 'password':
        d = PasswordDialog(args.text)
    
    if args.mode == 'credentials':
        d = CredentialsDialog(args.text)
    
    if args.mode == 'keyfile':
        d = KeyfileDialog(args.text)
    
    if args.mode == 'notification-information':
        d = NotificationDialog('OpenSecurity Information', args.text)
    
    if args.mode == 'notification-warning':
        d = NotificationDialog('OpenSecurity Warning', args.text)
    
    if args.mode == 'notification-critical':
        d = NotificationDialog('OpenSecurity Critical Message', args.text)
        
    if not 'd' in locals():
        sys.stderr.write('unknown mode. type --help for help\n')
        sys.exit(1)
    
    # pop up the dialog
    d.show()
    a.exec_()
    
    # give proper result code
    if d.result() == QtGui.QDialog.Accepted:
        res = 0
    else:
        res = 1
    sys.exit(res)
    

# start
if __name__ == "__main__":
    main()

